summaryrefslogtreecommitdiff
path: root/test/bootstrap/noseplugin.py
diff options
context:
space:
mode:
Diffstat (limited to 'test/bootstrap/noseplugin.py')
-rw-r--r--test/bootstrap/noseplugin.py8
1 files changed, 5 insertions, 3 deletions
diff --git a/test/bootstrap/noseplugin.py b/test/bootstrap/noseplugin.py
index 156a18514..c43e81f70 100644
--- a/test/bootstrap/noseplugin.py
+++ b/test/bootstrap/noseplugin.py
@@ -89,8 +89,8 @@ class NoseSQLAlchemy(Plugin):
fn(self.options, file_config)
def begin(self):
- global testing, requires, util, fixtures
- from test.lib import testing, requires, fixtures
+ global testing, requires, util, fixtures, engines
+ from test.lib import testing, requires, fixtures, engines
from sqlalchemy import util
testing.db = db
@@ -170,9 +170,11 @@ class NoseSQLAlchemy(Plugin):
testing.resetwarnings()
def afterTest(self, test):
+ engines.testing_reaper._after_test_ctx()
testing.resetwarnings()
- def afterContext(self):
+ def stopContext(self, ctx):
+ engines.testing_reaper._stop_test_ctx()
testing.global_cleanup_assertions()
#def handleError(self, test, err):